<template>
  <BaseChart
    v-slot="{ options }"
    :options="chartOptions"
  >
    <LineChart
      :data="chartData"
      :options="options"
    />
  </BaseChart>
</template>

<script lang="ts" setup>
import { Line as LineChart } from "vue-chartjs";
import type { ChartData, ChartOptions } from "chart.js";
import { transparentize } from "color2k";
import BaseChart from "@/js/contexts/shared/ui/components/charts/BaseChart.vue";

const props = defineProps<{
  values: DataSet[];
  labels: string[];
}>();

export type DataSet = {
  values: number[];
  color: string;
  label: string;
};

const { t } = useI18n();

const chartData = computed(() => {
  return {
    labels: props.labels ?? [],
    datasets: props.values.map((item) => ({
      label: t(item.label),
      data: item.values ?? [],
      borderColor: item.color,
      backgroundColor: transparentize(item.color, 0.7),
      pointBorderColor: "transparent",
      pointHoverBorderColor: item.color,
      pointBorderWidth: 3,
      tension: 0.2,
    })),
  } satisfies ChartData<"line">;
});
const chartOptions = computed(() => {
  return {
    scales: {
      x: {
        border: {
          dash: [4, 4],
          color: "rgba(17,24,39,0.1)",
        },
        grid: {
          drawTicks: false,
          color: "rgba(209,213,219,1)",
        },
        ticks: {
          color: "rgba(17,24,39,1)",
          padding: 16,
        },
      },
      y: {
        beginAtZero: true,
        border: {
          display: false,
        },
        grid: {
          display: false,
        },
        ticks: {
          color: "rgba(17,24,39,1)",
          stepSize: 1,
          padding: 6,
        },
      },
    },
    elements: {
      line: {
        borderWidth: 2,
      },
      point: {
        radius: 1,
        backgroundColor: "transparent",
        borderWidth: 0,
        hoverBackgroundColor: "white",
        hoverRadius: 4,
        hoverBorderWidth: 2,
      },
    },
    interaction: { intersect: false, mode: "index" },
  } satisfies ChartOptions<"line">;
});
</script>
